@@ -250,34 +250,8 @@ class PMF(object):
         self.species = [newTotalVar if x == self.totalVar else x for x in self.species]
         self.totalVar = newTotalVar
 
-    def rename_profile_to_profile_category(self):
-        """Rename the factor profile name to match the category
-
-        See pyPMF.utils.get_sourcesCategories
-        """
-        DF = [
-            self.dfprofiles_b,
-            self.dfprofiles_c,
-            self.dfcontrib_b,
-            self.dfcontrib_c,
-            self.dfBS_profile_b,
-            self.dfBS_profile_c,
-            self.df_uncertainties_summary_b,
-            self.df_uncertainties_summary_c,
-        ]
-        possible_sources = {p: get_sourcesCategories([p])[0] for p in self.profiles}
-        for df in DF:
-            if df is None:
-                continue
-            if df.index.dtype == 'O':
-                df.rename(possible_sources, inplace=True, axis="index")
-            if df.columns.dtype == 'O':
-                df.rename(possible_sources, inplace=True, axis="columns")
-
-        self.profiles = [possible_sources[p] for p in self.profiles]
-
-    def rename_profile(self, mapper):
-        """Rename a factor profile
+    def rename_factors(self, mapper):
+        """Rename factors names in all dataframe
 
         Parameters
         ----------
@@ -298,11 +272,21 @@ class PMF(object):
         for df in DF:
             if df is None:
                 continue
-            df.rename(mapper, inplace=True, axis=1)
-            df.rename(mapper, inplace=True, axis=0)
+            if df.index.dtype == 'O':
+                df.rename(mapper, inplace=True, axis="index")
+            if df.columns.dtype == 'O':
+                df.rename(mapper, inplace=True, axis="columns")
 
         self.profiles = [mapper.get(p, p) for p in self.profiles]
 
+    def rename_factors_to_factors_category(self):
+        """Rename the factor profile name to match the category
+
+        See pyPMF.utils.get_sourcesCategories
+        """
+        possible_sources = {p: get_sourcesCategories([p])[0] for p in self.profiles}
+        self.rename_factors(possible_sources)
+
     def recompute_new_species(self, specie):
         """Recompute a specie given the other species. For instance, recompute OC
         from OC* and a list of organic species.
